package com.sooka.system.mapper;

import java.util.List;
import com.sooka.system.domain.TUSfz;

/**
 * 身份证Mapper接口
 * 
 * @author lei
 * @date 2021-07-06
 */
public interface TUSfzMapper 
{
    /**
     * 查询身份证
     * 
     * @param id 身份证ID
     * @return 身份证
     */
    public TUSfz selectTUSfzById(String id);

    /**
     * 查询身份证列表
     * 
     * @param tUSfz 身份证
     * @return 身份证集合
     */
    public List<TUSfz> selectTUSfzList(TUSfz tUSfz);

    /**
     * 新增身份证
     * 
     * @param tUSfz 身份证
     * @return 结果
     */
    public int insertTUSfz(TUSfz tUSfz);

    /**
     * 修改身份证
     * 
     * @param tUSfz 身份证
     * @return 结果
     */
    public int updateTUSfz(TUSfz tUSfz);

    /**
     * 删除身份证
     * 
     * @param id 身份证ID
     * @return 结果
     */
    public int deleteTUSfzById(String id);

    /**
     * 批量删除身份证
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTUSfzByIds(String[] ids);
}
